@@ -18,16 +18,14 @@ class CommandLineArguments : public QObject
     Q_OBJECT
     Q_PROPERTY(QString pageId READ pageId CONSTANT)
     Q_PROPERTY(QString pageName READ pageName CONSTANT)
-    Q_PROPERTY(QVariant aboutData READ aboutData CONSTANT)
     QML_ELEMENT
     QML_SINGLETON
 
 public:
-    CommandLineArguments(QObject *parent = nullptr);
+    explicit CommandLineArguments(QObject *parent = nullptr);
 
     QString pageId() const;
     QString pageName() const;
-    QVariant aboutData() const;
 
     static void setCommandLineParser(std::shared_ptr<QCommandLineParser> parser);
 
